.. WordEmbeddingLoader documentation master file, created by
   sphinx-quickstart on Sun May 28 16:50:42 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to chainerboard's documentation!
===============================================

.. include:: ../../README.rst

.. include:: ../../CHANGELOG.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
